
Wutta-Continuum
===============

This package adds data versioning/history for `WuttJamaican`_, using
`SQLAlchemy-Continuum`_.

.. _WuttJamaican: https://rattailproject.org/docs/wuttjamaican/

.. _SQLAlchemy-Continuum: https://sqlalchemy-continuum.readthedocs.io/en/latest/


.. toctree::
   :maxdepth: 2
   :caption: Documentation

   narr/install

.. toctree::
   :maxdepth: 1
   :caption: API

   api/wutta_continuum
   api/wutta_continuum.app
   api/wutta_continuum.conf
